summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/networkstatuscommon.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/networkstatuscommon.h')
-rw-r--r--kopete/libkopete/networkstatuscommon.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/networkstatuscommon.h b/kopete/libkopete/networkstatuscommon.h
index 81ac8350..1d36b5c0 100644
--- a/kopete/libkopete/networkstatuscommon.h
+++ b/kopete/libkopete/networkstatuscommon.h
@@ -19,8 +19,8 @@ namespace NetworktqStatus
TQCString service;
// indicate that the connection is to 'the internet' - similar to default gateway in routing
bool internet;
- // list of nettqmasks that the network connects to - overridden by above internet
- TQStringList nettqmasks;
+ // list of netmasks that the network connects to - overridden by above internet
+ TQStringList netmasks;
// for future expansion consider
// EnumChargingModel - FlatRate, TimeCharge, VolumeCharged
// EnumLinktqStatus - for WLANs - VPOOR, POOR, AVERAGE, GOOD, EXCELLENT